Sejlersko til dame og herre - Find sejlersko til kvinder og mænd her
Description: Find smarte sejlersko til damer og herrer online hos katoni.dk. Vi har et enormt udvalg og altid masser af rigtig gode tilbud.

gemte varer

# Sejlersko

Herre Dame Kun udsalg Spar mest Kun gratis fragt Kun gratis retur
36
36½
37
37½
38
38½
39
39½
40
40½
41
41½
42
42½
43
43½
44
44½
45
45½
46
46½
47
47½
48
49
50
Luk filter
Størrelse
Army
Beige
Blandet
Blå
Brun
Grå
Guld
Hvid
Lilla
Lyserød
Orange
Rød
Sort
Sølv
Luk filter
Farve
Ingen mærker passede til søgningen
Allen Edmonds sejlersko
ara sejlersko
Barracuda sejlersko
Boemos sejlersko
Caprice sejlersko
Casual Attitude sejlersko
ETRO sejlersko
Faconnable sejlersko
Gaastra sejlersko
Hackett sejlersko
Panama Jack sejlersko
Penguin sejlersko
Sebago sejlersko
Serge Blanco sejlersko
Skechers sejlersko
Snipe sejlersko
Sperry Top-Sider sejlersko
TBS sejlersko
Think sejlersko
Timberland sejlersko
Boemos sejlersko
Sonia Rykiel sejlersko
ETRO sejlersko
Sperry Top-Sider sejlersko
Caprice sejlersko
Gaastra sejlersko
Panama Jack sejlersko
ara sejlersko
Sebago sejlersko
Stonefly sejlersko
TBS sejlersko
Hackett sejlersko
Faconnable sejlersko
Casual Attitude sejlersko
n.d.c. sejlersko
Snipe sejlersko
Serge Blanco sejlersko
Allen Edmonds sejlersko
Think sejlersko
Timberland sejlersko
Fluchos sejlersko
Clarks sejlersko
Barracuda sejlersko
Penguin sejlersko
Napapijri sejlersko
Skechers Performance Division sejlersko
Skechers sejlersko
Luk filter
Mærke
Pris lav til høj
Spar mest
Luk filter
Sortering

Sejlersko Tbs Globek
Str.: Findes i 8 størrelser
1084,00 DKK 1.084,00
Gem Fjern Køb
Sejlersko Sebago Docksides
Str.: Findes i 5 størrelser
1091,00 DKK 1.091,00
Gem Fjern Køb
-20%
Sejlersko Etro Mocassin 3705
Str.: 36 / 37 / 38 / 39
1996,00 DKK 1.996,00 DKK 2.495,00
Gem Fjern Køb
-20%
Sejlersko Etro E1670
Str.: 42 / 43 / 44 / 45
2251,00 DKK 2.251,00 DKK 2.814,00
Gem Fjern Køb
-20%
Sejlersko Façonnable Rene
Str.: Findes i 7 størrelser
1216,00 DKK 1.216,00 DKK 1.520,00
Gem Fjern Køb
-20%
Sejlersko Sonia Rykiel Capaia
Str.: 37 / 38 / 39
1840,00 DKK 1.840,00 DKK 2.300,00
Gem Fjern Køb
-20%
Sejlersko Fluchos Poseidon
Str.: 39 / 41
717,00 DKK 717,00 DKK 896,00
Gem Fjern Køb
Sejlersko Skechers Diamonback Leroy
Str.: Findes i 8 størrelser
506,00 DKK 506,00
Gem Fjern Køb
-20%
Sejlersko Sperry Topsider Ao Two Eye
Str.: 37 / 38 / 39 / 40
748,00 DKK 748,00 DKK 935,00
Gem Fjern Køb
Sejlersko Casual Attitude Everoa
Str.: Findes i 7 størrelser
507,00 DKK 507,00
Gem Fjern Køb
Sejlersko Timberland Classic 2 Eye
Str.: 41 / 49 / 50
974,00 DKK 974,00
Gem Fjern Køb
Sejlersko Sebago Spinnaker
Str.: 36 / 41
1052,00 DKK 1.052,00
Gem Fjern Køb
-20%
Sejlersko Sperry Topsider Ao Two Eye
Str.: 37 / 38
624,00 DKK 624,00 DKK 780,00
Gem Fjern Køb
-20%
Sejlersko Sperry Topsider Ao Two Eye
Str.: 37 / 38 / 39
624,00 DKK 624,00 DKK 780,00
Gem Fjern Køb
-40%
Sejlersko Penguin -
Str.: 41 / 43
421,00 DKK 421,00 DKK 702,00
Gem Fjern Køb
-20%
Sejlersko Gaastra Halyard
Str.: 37 / 38 / 40 / 41
623,00 DKK 623,00 DKK 779,00
Gem Fjern Køb
-20%
Sejlersko Clarks Marcos Edge
Str.: 42 1/2 / 40
561,00 DKK 561,00 DKK 701,00
Gem Fjern Køb
-20%
Sejlersko Tbs Pattye
Str.: 39 / 40
530,00 DKK 530,00 DKK 663,00
Gem Fjern Køb
Sejlersko Timberland Classic 2 Eye
Str.: 47 1/2 / 42 / 50
974,00 DKK 974,00
Gem Fjern Køb
-20%
Sejlersko Think Hedu
Str.: 42 / 44 / 45
991,00 DKK 991,00 DKK 1.239,00
Gem Fjern Køb
-20%
Sejlersko Snipe Aragon 100
Str.: 42 / 43 / 45
935,00 DKK 935,00 DKK 1.169,00
Gem Fjern Køb
Panama Jack Panisi Sejlersko Velours Grass Miel
Str.: 39 / 40
899,00 DKK 899,00
Gem Fjern Køb
-20%
Sejlersko Hackett Classic Dockside
Str.: Findes i 6 størrelser
966,00 DKK 966,00 DKK 1.208,00
Gem Fjern Køb
Sejlersko Sebago Docksides
Str.: Findes i 11 størrelser
1130,00 DKK 1.130,00
Gem Fjern Køb
Sejlersko Sperry Topsider Bahama 2eye Lthr
Str.: Findes i 5 størrelser
702,00 DKK 702,00
Gem Fjern Køb
-20%
Sejlersko Sebago Docksides
Str.: 39 / 40
842,00 DKK 842,00 DKK 1.052,00
Gem Fjern Køb
Sejlersko Sebago Docksides
Str.: Findes i 12 størrelser
1130,00 DKK 1.130,00
Gem Fjern Køb
-20%
Sejlersko Hackett Bamba Dside
Str.: 40 / 41 / 43 / 45
748,00 DKK 748,00 DKK 935,00
Gem Fjern Køb
-20%
Sejlersko Hackett Classic Dockside
Str.: 40 / 41
966,00 DKK 966,00 DKK 1.208,00
Gem Fjern Køb
Sejlersko Sebago Spinnaker
Str.: Findes i 5 størrelser
1091,00 DKK 1.091,00
Gem Fjern Køb
-20%
Sejlersko Tbs Pattye
Str.: Findes i 5 størrelser
530,00 DKK 530,00 DKK 663,00
Gem Fjern Køb
-20%
Sejlersko Façonnable Henri
Str.: 39 / 40 / 41
1528,00 DKK 1.528,00 DKK 1.910,00
Gem Fjern Køb
-20%
Sejlersko Sperry Topsider Ao Stonewashed
Str.: 40 1/2 / 42
562,00 DKK 562,00 DKK 702,00
Gem Fjern Køb
Sejlersko Sperry Topsider Ao 2 Eye
Str.: Findes i 6 størrelser
935,00 DKK 935,00
Gem Fjern Køb
Sejlersko Timberland 3 Eye Classic Lug
Str.: Findes i 8 størrelser
1286,00 DKK 1.286,00
Gem Fjern Køb
-20%
Loafers Panama Jack Panisi
Str.: 37 / 40
680,00 DKK 680,00 DKK 850,00
Gem Fjern Køb
-20%
Loafers Panama Jack Panisi
Str.: Findes i 5 størrelser
680,00 DKK 680,00 DKK 850,00
Gem Fjern Køb
-20%
Sejlersko Gaastra Halyard
Str.: 38 / 40 / 41
623,00 DKK 623,00 DKK 779,00
Gem Fjern Køb
Sejlersko Sebago Schooner
Str.: Findes i 8 størrelser
1130,00 DKK 1.130,00
Gem Fjern Køb
-20%
Sejlersko Etro Mocassin 3773
Str.: Findes i 6 størrelser
2370,00 DKK 2.370,00 DKK 2.962,00
Gem Fjern Køb
-20%
Sejlersko Sperry Topsider Suede
Str.: Findes i 6 størrelser
624,00 DKK 624,00 DKK 780,00
Gem Fjern Køb
-20%
Sejlersko Etro 3985
Str.: 37 / 38 / 39 / 40
2514,00 DKK 2.514,00 DKK 3.142,00
Gem Fjern Køb
Sejlersko Casual Attitude Everoa
Str.: Findes i 6 størrelser
507,00 DKK 507,00
Gem Fjern Køb
Sejlersko Tbs Homard
Str.: Findes i 5 størrelser
772,00 DKK 772,00
Gem Fjern Køb
-20%
Sejlersko Allen Edmonds South Sore
Str.: 40 / 44
1372,00 DKK 1.372,00 DKK 1.715,00
Gem Fjern Køb
-20%
Sejlersko Sperry Topsider Ao Two Eye Canvas
Str.: 40 1/2 / 43 / 44
624,00 DKK 624,00 DKK 780,00
Gem Fjern Køb
-20%
Sejlersko Barracuda Tinno
Str.: 45 / 46
1232,00 DKK 1.232,00 DKK 1.540,00
Gem Fjern Køb
-20%
Sejlersko Façonnable Henri
Str.: 39 / 40 / 41 / 46
1528,00 DKK 1.528,00 DKK 1.910,00
Gem Fjern Køb
-20%
Sejlersko Sperry Topsider Ao Two Eye
Str.: 36 / 37 / 39
624,00 DKK 624,00 DKK 780,00
Gem Fjern Køb
-20%
Sejlersko Sperry Topsider Suede
Str.: 44 1/2 / 45 1/2 / 42 / 45
624,00 DKK 624,00 DKK 780,00
Gem Fjern Køb
-40%
Sperry Topsider Sejlersko Blå
Str.: Findes i 8 størrelser
569,00 DKK 569,00 DKK 949,00
Gem Fjern Køb
-20%
Sejlersko Hackett Mocassins Bow
Str.: 40 / 45
1091,00 DKK 1.091,00 DKK 1.364,00
Gem Fjern Køb
-20%
Sejlersko Gaastra Safari Vintage
Str.: 40 / 41
561,00 DKK 561,00 DKK 701,00
Gem Fjern Køb
Sejlersko Casual Attitude Revoro
Str.: Findes i 6 størrelser
468,00 DKK 468,00
Gem Fjern Køb
-20%
Sejlersko Façonnable Henri
Str.: 39 / 40
1528,00 DKK 1.528,00 DKK 1.910,00
Gem Fjern Køb
-20%
Sejlersko Etro Chaussure Bateau E1525
Str.: 40 / 41
2338,00 DKK 2.338,00 DKK 2.923,00
Gem Fjern Køb
Sejlersko Sebago Docksides
Str.: Findes i 12 størrelser
1130,00 DKK 1.130,00
Gem Fjern Køb
-20%
Sejlersko Hackett Mocassins Bow
Str.: 40 / 41 / 43 / 45
1091,00 DKK 1.091,00 DKK 1.364,00
Gem Fjern Køb
-20%
Sejlersko Serge Blanco Badsey
Str.: Findes i 5 størrelser
1154,00 DKK 1.154,00 DKK 1.442,00
Gem Fjern Køb
Sejlersko Sebago Docksides
Str.: Findes i 6 størrelser
1130,00 DKK 1.130,00
Gem Fjern Køb
-20%
Sejlersko Façonnable Jacques
Str.: 39 / 40 / 41 / 44
1029,00 DKK 1.029,00 DKK 1.286,00
Gem Fjern Køb
-20%
Sejlersko Façonnable Henri
Str.: 39 / 40 / 41 / 42
1528,00 DKK 1.528,00 DKK 1.910,00
Gem Fjern Køb
-20%
Sejlersko Napapijri Nansen
Str.: 43 / 44
904,00 DKK 904,00 DKK 1.130,00
Gem Fjern Køb
Sejlersko Sperry Topsider Bahama 2eye Lthr
Str.: 42 / 43 / 44
702,00 DKK 702,00
Gem Fjern Køb
Sejlersko Tbs Sharks
Str.: Findes i 7 størrelser
701,00 DKK 701,00
Gem Fjern Køb
-20%
Sejlersko Boemos Vivel W
Str.: 36 / 39 / 40
555,00 DKK 555,00 DKK 694,00
Gem Fjern Køb
Sejlersko Sperry Topsider A O Lug Chukka Wp
Str.: Findes i 6 størrelser
1091,00 DKK 1.091,00
Gem Fjern Køb
-20%
Sejlersko Skechers Go Bionic Brizo-
Str.: Findes i 9 størrelser
530,00 DKK 530,00 DKK 662,00
Gem Fjern Køb
Sejlersko Tbs Globek
Str.: Findes i 8 størrelser
1084,00 DKK 1.084,00
Gem Fjern Køb
Sejlersko Sebago Docksides
Str.: Findes i 9 størrelser
1130,00 DKK 1.130,00
Gem Fjern Køb
Sejlersko Sebago Spinnaker
Str.: Findes i 5 størrelser
1091,00 DKK 1.091,00
Gem Fjern Køb
-20%
Sejlersko Sperry Topsider Cruiser
Str.: 38 / 39 / 40
406,00 DKK 406,00 DKK 507,00
Gem Fjern Køb
Sejlersko Sebago Schooner
Str.: Findes i 8 størrelser
1130,00 DKK 1.130,00
Gem Fjern Køb
-20%
Sejlersko Etro Mocassin 3773
Str.: 36 / 37 / 39
2370,00 DKK 2.370,00 DKK 2.962,00
Gem Fjern Køb
Sejlersko Casual Attitude Revoro
Str.: Findes i 7 størrelser
468,00 DKK 468,00
Gem Fjern Køb
Sejlersko Tbs Phenis
Str.: Findes i 6 størrelser
741,00 DKK 741,00
Gem Fjern Køb
-20%
Sejlersko Hackett Bamba Dside
Str.: Findes i 7 størrelser
779,00 DKK 779,00 DKK 974,00
Gem Fjern Køb
Sejlersko Tbs Phenis
Str.: Findes i 8 størrelser
741,00 DKK 741,00
Gem Fjern Køb
Sejlersko Tbs Hauban
Str.: 41 / 42
772,00 DKK 772,00
Gem Fjern Køb
Sejlersko Casual Attitude Revoro
Str.: Findes i 5 størrelser
468,00 DKK 468,00
Gem Fjern Køb
-20%
Sejlersko Stonefly Filud
Str.: 36 / 37 / 38
593,00 DKK 593,00 DKK 741,00
Gem Fjern Køb
Sejlersko Sebago Docksides
Str.: Findes i 11 størrelser
1130,00 DKK 1.130,00
Gem Fjern Køb
-20%
Sejlersko Sperry Topsider Ao Two Eye
Str.: 39 / 40
748,00 DKK 748,00 DKK 935,00
Gem Fjern Køb
-20%
Sejlersko Sperry Topsider Ao Two Eye
Str.: Findes i 5 størrelser
562,00 DKK 562,00 DKK 702,00
Gem Fjern Køb
-20%
Sejlersko N D C Dyno Piuma Nubuck
Str.: 41 / 42
1559,00 DKK 1.559,00 DKK 1.949,00
Gem Fjern Køb
-20%
Sejlersko Caprice Lenka
Str.: 37 1/2 / 38 1/2 / 40 1/2
368,00 DKK 368,00 DKK 460,00
Gem Fjern Køb
-40%
Sperry Topsider Bahama Sejlersko Oliven
Str.: Findes i 6 størrelser
389,00 DKK 389,00 DKK 649,00
Gem Fjern Køb
-45%
Sperry Topsider Sejlersko Brun
Str.: Findes i 6 størrelser
521,00 DKK 521,00 DKK 949,00
Gem Fjern Køb
-20%
Sejlersko Hackett Bamba Dside
Str.: 40 / 41 / 42 / 43
748,00 DKK 748,00 DKK 935,00
Gem Fjern Køb
Sejlersko Sperry Topsider Ao 2 Eye
Str.: 41 1/2 / 44 1/2 / 44
935,00 DKK 935,00
Gem Fjern Køb
-20%
Sejlersko Boemos Vivel W
Str.: 40 / 41
555,00 DKK 555,00 DKK 694,00
Gem Fjern Køb
-20%
Sejlersko Façonnable Jacques
Str.: 45 / 46
1029,00 DKK 1.029,00 DKK 1.286,00
Gem Fjern Køb
-20%
Sejlersko Sperry Topsider Ao 2eye
Str.: 36 / 37
748,00 DKK 748,00 DKK 935,00
Gem Fjern Køb
Sejlersko Sebago Docksides
Str.: Findes i 8 størrelser
1130,00 DKK 1.130,00
Gem Fjern Køb
-20%
Sejlersko Gaastra Safari
Str.: 36 / 41
561,00 DKK 561,00 DKK 701,00
Gem Fjern Køb
-20%
Sejlersko Serge Blanco Lionello
Str.: 40 / 41 / 42 / 45
867,00 DKK 867,00 DKK 1.084,00
Gem Fjern Køb
Sejlersko Timberland Classic 2 Eye
Str.: 49 / 50
974,00 DKK 974,00
Gem Fjern Køb
-20%
Sejlersko Boemos Vivel W
Str.: 36 / 37 / 38 / 39
555,00 DKK 555,00 DKK 694,00
Gem Fjern Køb
-20%
Sejlersko Sperry Topsider Cason
Str.: 36 / 37
717,00 DKK 717,00 DKK 896,00
Gem Fjern Køb
Sejlersko Tbs Globek
Str.: Findes i 7 størrelser
1084,00 DKK 1.084,00
Gem Fjern Køb

## Stort udvalg af sejlersko online

Sejlersko skaber let et preppy look. Som navnet antyder blev sejlersko oprindeligt lavet for bedre at kunne stå fast på båddækket det olierede læder kan modstå vand og gummisålen har et bedre greb. Men disse sko har også længe været at finde i modens verden, og skoen er endnu en vigtig del af det amerikanske preppy look, ofte tilsat blazer og chinos. Det er desuden en skøn sommersko, og mangler du sådan et par i din skosamling, så er du kommet det helt rigtige sted hen.

Her på katoni.dk har vi samlet nogle af de bedste danske og udenlandske online shops, og vi har derfor også et stort udvalg af de lækre lædersko. Sorteringsmulighederne hjælper dig med at finde frem til det par, du lige står og mangler. Søg på størrelse, farve eller mærke og udvalget bliver sorteret, så du kun bliver præsenteret for de sko, der matcher din søgning. Vi håber, du finder det helt rigtige par sejlersko. Og er de alligevel ikke sagen, så er både espadriller og loafers også fede udgaver af de lette sommersko!

## Maritimt look med sejlerskoen til kvinder

Det maritime look er en sikker vinder, når solen skinner og vandet lokker. Og den skønne og behagelige dame sejlersko er den perfekte sko til lejligheden. Hvad end du står overfor at skulle tilbringe dagen på havet eller indendørs på studiet eller jobbet, så er det maritime look en forårsklassiker. Kombiner et par blå sejlersko med hvide snøre med hvide skinny jeans og en sømandsstribet bluse. Outfittet er simpelt, men bestemt også forårsfint.

Et andet nemt outfit består af et par råhvide sejlersko, en blå-hvid stribet blusekjole og en oversize denim skjorte, der er bundet om livet. Super maritimt, og hvis du har brug for lidt ekstra coolness, så husk masser af smykker og en beigefarvet trenchcoat over skuldrene! Sejlersko til kvinder emmer af sommer, og det er derfor oplagt at bruge dem med bare ben. Et par i en humørfyldt farve er det perfekte match til et simpelt outfit bestående af en kort nederdel og løs t-shirt eller let strik. Dame sejlerskoen sikrer dig et stilsikkert og super enkelt look sommeren igennem!

## Masser af coolness med herre sejlerskoen

Herre sejlerskoen giver dig en snert af det preppy look. Og har du lyst til at gennemføre stilen, så er de marineblå sejlersko et perfekt match til opsmøgede jeans, skjorte og en lækker, mørkeblå uldblazer. Skal det preppy look opdateres, kan du vælge et par tofarvede sejlersko tilsat mørkeblå chinos med oprul og en af sæsonens lækre, mønstrede skjorter. Og selvom strømper i sejlersko normalvis er absolut forbudt, kan dette outfit godt bære et par klare blå strømper.

Sejlerskoen giver også lidt casual coolness til det matchende herresæt. Føler du ikke for at springe ud i et mønstret et af slagsen, så er det bordeauxfarvede sæt bestående af chinos og jakke rigtig fedt. Husk at køre stilen afslappet, og tag en sort t-shirt og en åben, grå skjorte indenunder jakken. Sættet er perfekt, hvis du sætter et par sort-brune sejlersko til.

Og så er sejlersko naturligvis også geniale til shorts! Et beigefarvet par gør det særdeles godt til et par grønne chinos shorts og en hvid skjorte. Skal den preppy stil skinne igennem, så bind en sort striktrøje om halsen!

## Masser af tilbud på sejlersko

Sejlerskoen er en klassisk sommersko. Så let som ingenting gør den din stil sommerlig, moderne og maritim. Så står du og mangler det der par sko, der giver din sommergarderobe det sidste touch af solferier, lyse nætter og kold hvidvin, så er sejlerskoen et godt valg.

Her på katoni.dk er udvalget af mærker stort, og sejlersko fra Sebago, Timerland og Sperry Top-Sider er nogle af de mest ikoniske. Jagter du derimod et par billige sejlersko, så har vi på katoni.dk altid tusindvis af varer på udsalg. Benyt dig af filtrene her på siden, og du bliver præsenteret for et stort udvalg af sejlersko på tilbud. Med disse sko går du sommeren i møde på absolut stilfuld og maritim vis.